aboutsummaryrefslogtreecommitdiffstats
path: root/lib/public/Contacts/ContactsMenu/IActionFactory.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/Contacts/ContactsMenu/IActionFactory.php')
-rw-r--r--lib/public/Contacts/ContactsMenu/IActionFactory.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/public/Contacts/ContactsMenu/IActionFactory.php b/lib/public/Contacts/ContactsMenu/IActionFactory.php
index 393c9eb487a..b4e4eb96819 100644
--- a/lib/public/Contacts/ContactsMenu/IActionFactory.php
+++ b/lib/public/Contacts/ContactsMenu/IActionFactory.php
@@ -35,10 +35,10 @@ interface IActionFactory {
* @param string $icon full path to the action's icon
* @param string $name localized name of the action
* @param string $href target URL
* @param string $appName the appName registering the action
* @return ILinkAction
*/
- public function newLinkAction(string $icon, string $name, string $href, string $appName = ''): ILinkAction;
+ public function newLinkAction(string $icon, string $name, string $href, string $appId = ''): ILinkAction;
/**
* Construct and return a new email action for the contacts menu
@@ -48,8 +48,8 @@ interface IActionFactory {
* @param string $icon full path to the action's icon
* @param string $name localized name of the action
* @param string $email target e-mail address
* @param string $appName the appName registering the action
* @return ILinkAction
*/
- public function newEMailAction(string $icon, string $name, string $email, string $appName = ''): ILinkAction;
+ public function newEMailAction(string $icon, string $name, string $email, string $appId = ''): ILinkAction;
}
@@ -35,10 +35,10 @@ interface IActionFactory {
* @param string $name localized name of the action
* @param string $href target URL
- * @param string $appName the appName registering the action
+ * @param string $appId the app ID registering the action
* @return ILinkAction
*/
@@ -48,8 +48,8 @@ interface IActionFactory {
* @param string $name localized name of the action
* @param string $email target e-mail address
- * @param string $appName the appName registering the action
+ * @param string $appId the appName registering the action
* @return ILinkAction
*/